import { Stack, StackSynthesizer, FileAssetSource, FileAssetLocation, DockerImageAssetLocation, DockerImageAssetSource, ISynthesisSession } from 'aws-cdk-lib';
import { IBucket } from 'aws-cdk-lib/aws-s3';
import { Construct } from 'constructs';
export declare const fileAssetResourceName = "StackSetAssetsBucketDeployment";
/**
 * Deployment environment for an AWS StackSet stack.
 *
 * Interoperates with the StackSynthesizer of the parent stack.
 */
export declare class StackSetStackSynthesizer extends StackSynthesizer {
    private readonly assetBucket?;
    private bucketDeployment?;
    constructor(assetBucket?: IBucket);
    addFileAsset(asset: FileAssetSource): FileAssetLocation;
    private physicalNameOfBucket;
    addDockerImageAsset(_asset: DockerImageAssetSource): DockerImageAssetLocation;
    synthesize(session: ISynthesisSession): void;
}
/**
 * StackSet stack props.
 */
export interface StackSetStackProps {
    /**
     * A Bucket can be passed to store assets, enabling StackSetStack Asset support
     * @default No Bucket provided and Assets will not be supported.
     */
    readonly assetBucket?: IBucket;
}
/**
 * A StackSet stack, which is similar to a normal CloudFormation stack with
 * some differences.
 *
 * This stack will not be treated as an independent deployment
 * artifact (won't be listed in "cdk list" or deployable through "cdk deploy"),
 * but rather only synthesized as a template and uploaded as an asset to S3.
 */
export declare class StackSetStack extends Stack {
    readonly templateFile: string;
    private _templateUrl?;
    private _parentStack;
    constructor(scope: Construct, id: string, props?: StackSetStackProps);
    /**
     * Fetch the template URL.
     *
     * @internal
     */
    _getTemplateUrl(): string;
    /**
     * Fetch the Parent Stack.
     *
     * @internal
     */
    _getParentStack(): Stack;
    /**
     * Synthesize the product stack template, overrides the `super` class method.
     *
     * Defines an asset at the parent stack which represents the template of this
     * product stack.
     *
     * @internal
     */
    _synthesizeTemplate(session: ISynthesisSession): void;
}
